pyYalgaar
---------
Yalgaar Python SDK for real-time messaging.

It supports Python 3.4 or newer.


Pip install
-----------

   ::

       pip install pyYalgaar

Getting started with Yalgaar Python SDK
---------------------------------------
`SDK Document <https://www.yalgaar.io/documentation/python-api>`_


Get in touch
------------
If you have any questions, `Contact Us <http://www.yalgaar.io/contact-us>`_


Visit us at
-----------
`www.yalgaar.io <http://www.yalgaar.io>`_